# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud.smartcaptcha.v1 import captcha_pb2 as yandex_dot_cloud_dot_smartcaptcha_dot_v1_dot_captcha__pb2
from yandex.cloud.smartcaptcha.v1 import captcha_service_pb2 as yandex_dot_cloud_dot_smartcaptcha_dot_v1_dot_captcha__service__pb2


class CaptchaServiceStub(object):
    """A set of methods for managing Captcha resources.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Get = channel.unary_unary(
                '/yandex.cloud.smartcaptcha.v1.CaptchaService/Get',
                request_serializer=yandex_dot_cloud_dot_smartcaptcha_dot_v1_dot_captcha__service__pb2.GetCaptchaRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_smartcaptcha_dot_v1_dot_captcha__pb2.Captcha.FromString,
                )
        self.GetSecretKey = channel.unary_unary(
                '/yandex.cloud.smartcaptcha.v1.CaptchaService/GetSecretKey',
                request_serializer=yandex_dot_cloud_dot_smartcaptcha_dot_v1_dot_captcha__service__pb2.GetCaptchaRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_smartcaptcha_dot_v1_dot_captcha__pb2.CaptchaSecretKey.FromString,
                )
        self.List = channel.unary_unary(
                '/yandex.cloud.smartcaptcha.v1.CaptchaService/List',
                request_serializer=yandex_dot_cloud_dot_smartcaptcha_dot_v1_dot_captcha__service__pb2.ListCaptchasRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_smartcaptcha_dot_v1_dot_captcha__service__pb2.ListCaptchasResponse.FromString,
                )
        self.Create = channel.unary_unary(
                '/yandex.cloud.smartcaptcha.v1.CaptchaService/Create',
                request_serializer=yandex_dot_cloud_dot_smartcaptcha_dot_v1_dot_captcha__service__pb2.CreateCaptchaRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.Update = channel.unary_unary(
                '/yandex.cloud.smartcaptcha.v1.CaptchaService/Update',
                request_serializer=yandex_dot_cloud_dot_smartcaptcha_dot_v1_dot_captcha__service__pb2.UpdateCaptchaRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.Delete = channel.unary_unary(
                '/yandex.cloud.smartcaptcha.v1.CaptchaService/Delete',
                request_serializer=yandex_dot_cloud_dot_smartcaptcha_dot_v1_dot_captcha__service__pb2.DeleteCaptchaRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )


class CaptchaServiceServicer(object):
    """A set of methods for managing Captcha resources.
    """

    def Get(self, request, context):
        """Returns the specified Captcha resource.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetSecretKey(self, request, context):
        """Returns the secret data of specified Captcha resource.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def List(self, request, context):
        """Retrieves the list of Captcha resources in the specified folder.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Create(self, request, context):
        """Creates a captcha in the specified folder using the data specified in the request.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Update(self, request, context):
        """Updates the specified captcha.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Delete(self, request, context):
        """Deletes the specified captcha.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_CaptchaServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Get': grpc.unary_unary_rpc_method_handler(
                    servicer.Get,
                    request_deserializer=yandex_dot_cloud_dot_smartcaptcha_dot_v1_dot_captcha__service__pb2.GetCaptchaRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_smartcaptcha_dot_v1_dot_captcha__pb2.Captcha.SerializeToString,
            ),
            'GetSecretKey': grpc.unary_unary_rpc_method_handler(
                    servicer.GetSecretKey,
                    request_deserializer=yandex_dot_cloud_dot_smartcaptcha_dot_v1_dot_captcha__service__pb2.GetCaptchaRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_smartcaptcha_dot_v1_dot_captcha__pb2.CaptchaSecretKey.SerializeToString,
            ),
            'List': grpc.unary_unary_rpc_method_handler(
                    servicer.List,
                    request_deserializer=yandex_dot_cloud_dot_smartcaptcha_dot_v1_dot_captcha__service__pb2.ListCaptchasRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_smartcaptcha_dot_v1_dot_captcha__service__pb2.ListCaptchasResponse.SerializeToString,
            ),
            'Create': grpc.unary_unary_rpc_method_handler(
                    servicer.Create,
                    request_deserializer=yandex_dot_cloud_dot_smartcaptcha_dot_v1_dot_captcha__service__pb2.CreateCaptchaRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'Update': grpc.unary_unary_rpc_method_handler(
                    servicer.Update,
                    request_deserializer=yandex_dot_cloud_dot_smartcaptcha_dot_v1_dot_captcha__service__pb2.UpdateCaptchaRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'Delete': grpc.unary_unary_rpc_method_handler(
                    servicer.Delete,
                    request_deserializer=yandex_dot_cloud_dot_smartcaptcha_dot_v1_dot_captcha__service__pb2.DeleteCaptchaRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'yandex.cloud.smartcaptcha.v1.CaptchaService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class CaptchaService(object):
    """A set of methods for managing Captcha resources.
    """

    @staticmethod
    def Get(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.smartcaptcha.v1.CaptchaService/Get',
            yandex_dot_cloud_dot_smartcaptcha_dot_v1_dot_captcha__service__pb2.GetCaptchaRequest.SerializeToString,
            yandex_dot_cloud_dot_smartcaptcha_dot_v1_dot_captcha__pb2.Captcha.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetSecretKey(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.smartcaptcha.v1.CaptchaService/GetSecretKey',
            yandex_dot_cloud_dot_smartcaptcha_dot_v1_dot_captcha__service__pb2.GetCaptchaRequest.SerializeToString,
            yandex_dot_cloud_dot_smartcaptcha_dot_v1_dot_captcha__pb2.CaptchaSecretKey.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def List(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.smartcaptcha.v1.CaptchaService/List',
            yandex_dot_cloud_dot_smartcaptcha_dot_v1_dot_captcha__service__pb2.ListCaptchasRequest.SerializeToString,
            yandex_dot_cloud_dot_smartcaptcha_dot_v1_dot_captcha__service__pb2.ListCaptchasResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Create(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.smartcaptcha.v1.CaptchaService/Create',
            yandex_dot_cloud_dot_smartcaptcha_dot_v1_dot_captcha__service__pb2.CreateCaptchaRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Update(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.smartcaptcha.v1.CaptchaService/Update',
            yandex_dot_cloud_dot_smartcaptcha_dot_v1_dot_captcha__service__pb2.UpdateCaptchaRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Delete(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.smartcaptcha.v1.CaptchaService/Delete',
            yandex_dot_cloud_dot_smartcaptcha_dot_v1_dot_captcha__service__pb2.DeleteCaptchaRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



from typing import TYPE_CHECKING, Optional

if TYPE_CHECKING:
    import google.protobuf.message

    from yandex.cloud.operation.operation_pb2 import Operation

    # from yandex.cloud.api.operation_pb2 import Operation


class OperationResult:
    def __init__(
        self,
        operation: "Operation",
        response: Optional["google.protobuf.message.Message"] = None,
        meta: Optional["google.protobuf.message.Message"] = None,
    ):
        self.operation = operation
        self.response = response
        self.meta = meta


class OperationError(RuntimeError):
    def __init__(self, message: str, operation_result: OperationResult):
        super(OperationError, self).__init__(message)  # pylint: disable=super-with-arguments
        self.message = message
        self.operation_result = operation_result



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/loadtesting/api/v1/config/config.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n3yandex/cloud/loadtesting/api/v1/config/config.proto\x12&yandex.cloud.loadtesting.api.v1.config\x1a\x1fgoogle/protobuf/timestamp.proto\"\x94\x01\n\x06\x43onfig\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\tfolder_id\x18\x02 \x01(\t\x12\x13\n\x0byaml_string\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\n \x01(\t\x12.\n\ncreated_at\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\ncreated_by\x18\x0c \x01(\tJ\x04\x08\x04\x10\nB\x7f\n*yandex.cloud.api.loadtesting.api.v1.configZQgithub.com/yandex-cloud/go-genproto/yandex/cloud/loadtesting/api/v1/config;configb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.loadtesting.api.v1.config.config_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n*yandex.cloud.api.loadtesting.api.v1.configZQgithub.com/yandex-cloud/go-genproto/yandex/cloud/loadtesting/api/v1/config;config'
  _globals['_CONFIG']._serialized_start=129
  _globals['_CONFIG']._serialized_end=277
# @@protoc_insertion_point(module_scope)
